@@ -15,13 +15,13 @@
 struct _GdbRegister
 {
     gchar name[10];
-    gchar value[20];
+    gchar value[50];
 };
 
 
 GList *gdb_list_sources (GdbInstance *inst);
 gchar *gdb_get_full_source_path (GdbInstance *inst, const gchar *file_name);
-GList *gdb_get_registers (GdbInstance *inst);
+GList *gdb_get_registers (GdbInstance *inst, gboolean floating_pt);
 void gdb_destroy_register_list (GdbInstance *inst, GList *regs);
 
 #endif
