@@ -104,6 +104,11 @@ start_gdb (GdbInstance *inst)
 
     gdb_start_listener (inst);
     gdb_execute_command (inst, "set height 0"); /* no "prompt-for-continue" */
+    
+    /* this drastically reduces the amount of worthless info that passes
+     * through gdb :) */
+    gdb_execute_command (inst, "set print elements 1");
+    
 
     return TRUE;
 }
