@@ -43,7 +43,7 @@ static void gdf_libdryad_debugger_class_init (GdfLibdryadDebuggerClass *class);
 static void gdf_libdryad_debugger_init (BonoboObject *object);
 static void connect_signals (GdfLibdryadDebugger *dbg);
 static void process_frame_change (GdfLibdryadDebugger *dbg);
-static void update_symsets (GdfLibdryadDebugger *dbg, gboolean include_locals);static void new_locals (GdfLibdryadDebugger *dbg);
+static void new_locals (GdfLibdryadDebugger *dbg);
 
 static BonoboObjectClass *parent_class;
 static POA_GDF_Debugger__epv libdryad_debugger_epv;
@@ -276,7 +276,7 @@ impl_detach (PortableServer_Servant servant,
     
     gdb_detach (dbg->gdb_inst);
     new_locals (dbg);
-    update_symsets (dbg, TRUE);
+    gdf_libdryad_debugger_update_symsets (dbg, TRUE);
     event_any = gdf_marshal_event_none ("detached");
     gdf_event_channel_client_push (dbg->event_channel, event_any);
     CORBA_free (event_any);
@@ -502,6 +502,7 @@ impl_get_breakpoint_info (PortableServer_Servant servant,
 
 static GDF_RegisterList *
 impl_get_registers (PortableServer_Servant servant,
+		    CORBA_boolean floating_pt,
 		    CORBA_Environment *ev)
 {
     GDF_RegisterList *ret;
@@ -515,7 +516,7 @@ impl_get_registers (PortableServer_Servant servant,
     CORBA_sequence_set_release (ret, CORBA_TRUE);
 
     if (dbg->gdb_inst) {
-	registers = gdb_get_registers (dbg->gdb_inst);
+	registers = gdb_get_registers (dbg->gdb_inst, floating_pt);
 	
 	if (registers) {
 	    num_regs = g_list_length (registers);
@@ -702,7 +703,8 @@ impl_step_out (PortableServer_Servant servant, CORBA_Environment *ev)
 /* Symbol watching */
 
 void
-update_symsets (GdfLibdryadDebugger *dbg, gboolean include_locals)
+gdf_libdryad_debugger_update_symsets (GdfLibdryadDebugger *dbg, 
+				      gboolean include_locals)
 {
     GList *i;
     
@@ -831,7 +833,7 @@ static void
 process_frame_change (GdfLibdryadDebugger *dbg)
 {
     new_locals (dbg);
-    update_symsets (dbg, FALSE);
+    gdf_libdryad_debugger_update_symsets (dbg, FALSE);
 }
 
 static void
@@ -904,7 +906,7 @@ execution_stopped_cb (GdfLibdryadDebugger *dbg)
     if (dbg->pending_exit != -1) {
 	dbg->state &= ~GDF_Debugger_TARGET_EXISTS;
 	new_locals (dbg);
-	update_symsets (dbg, TRUE);
+	gdf_libdryad_debugger_update_symsets (dbg, TRUE);
 	event_any = gdf_marshal_event_long ("exited", 
 					    (glong)dbg->pending_exit);
 	dbg->event_queue = g_list_prepend (dbg->event_queue, event_any);
@@ -918,7 +920,7 @@ execution_stopped_cb (GdfLibdryadDebugger *dbg)
 	    process_frame_change (dbg);
 	    dbg->frame_changed = FALSE;
 	} else {
-	    update_symsets (dbg, TRUE);
+	    gdf_libdryad_debugger_update_symsets (dbg, TRUE);
 	}
     }
     
