@@ -45,6 +45,8 @@ typedef struct
 GdfLibdryadDebugger *gdf_libdryad_debugger_new (void);
 GtkType gdf_libdryad_debugger_get_type (void);
 
+void gdf_libdryad_debugger_update_symsets (GdfLibdryadDebugger *dbg, 
+					   gboolean include_locals);
 END_GNOME_DECLS
 
 #endif
