@@ -218,6 +218,7 @@ impl_get_symbol (PortableServer_Servant servant,
     ret->value = CORBA_string_dup (sym->value);
     ret->type = sym->type;
     ret->typename = CORBA_string_dup (sym->typename);
+    ret->cast_to = CORBA_string_dup (sym->cast_to);
     ret->expandable = sym->expandable;
 	
 	ret->expanded = FALSE;
@@ -267,6 +268,7 @@ impl_get_symbol_children (PortableServer_Servant servant,
     ret = GDF_SymbolSequence__alloc ();
 
     sym = find_sym_by_id (ss, id);
+	
     g_return_val_if_fail (sym->expandable, ret);
     
 	if (!sym->expanded) {
@@ -283,14 +285,52 @@ impl_get_symbol_children (PortableServer_Servant servant,
     return ret;
 }
 
+static void
+impl_set_symbol_value (PortableServer_Servant servant,
+					   CORBA_long id,
+					   const CORBA_char *value,
+					   CORBA_Environment *ev)
+{
+    GdfLibdryadSymbolSet *ss = libdryad_symbol_set_from_servant (servant);
+	GdbSymbolResult res;
+	GDF_Symbol *sym;
+
+    sym = find_sym_by_id (ss, id);
+	res = gdb_set_symbol_value (ss->dbg->gdb_inst, sym, value);
+	if (res == GDB_SYMBOL_INVALID_TYPE) {
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+								 ex_GDF_Debugger_InvalidState, NULL);
+	}
+	
+	gdf_libdryad_debugger_update_symsets (ss->dbg, TRUE);
+}
+
+static void
+impl_cast (PortableServer_Servant servant,
+		   CORBA_long id,
+		   const CORBA_char *type,
+		   CORBA_Environment *ev)
+{
+    GdfLibdryadSymbolSet *ss = libdryad_symbol_set_from_servant (servant);
+	GdbSymbolResult res;
+	GDF_Symbol *sym;
+
+    sym = find_sym_by_id (ss, id);
+	res = gdb_cast (ss->dbg->gdb_inst, ss, sym, type);
+	if (res == GDB_SYMBOL_INVALID_TYPE) {
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+								 ex_GDF_Debugger_InvalidState, NULL);
+	}
+	
+	gdf_libdryad_debugger_update_symsets (ss->dbg, TRUE);
+}
+
 static CORBA_Object
 impl_get_event_channel (PortableServer_Servant servant,
 						CORBA_Environment *ev)
 {
     CORBA_Object ret;
     GdfLibdryadSymbolSet *ss = libdryad_symbol_set_from_servant (servant);
-	
-	GDF_TRACE ();
 
     ret = bonobo_object_corba_objref (BONOBO_OBJECT (ss->event_channel));
     return CORBA_Object_duplicate (ret, ev);
@@ -304,6 +344,8 @@ init_libdryad_symbol_set_corba_class (void)
     libdryad_symbol_set_epv.add_expression = impl_add_expression;
     libdryad_symbol_set_epv.get_symbol = impl_get_symbol;
     libdryad_symbol_set_epv.get_symbol_children = impl_get_symbol_children;
+	libdryad_symbol_set_epv.set_symbol_value = impl_set_symbol_value;
+	libdryad_symbol_set_epv.cast = impl_cast;	
     libdryad_symbol_set_epv.get_event_channel = impl_get_event_channel;
    
     /* VEPV */
