@@ -34,7 +34,7 @@ static GdfVariableViewerClass *parent_class;
  */
 
 GtkType
-gdf_locals_viewer_get_type ()
+gdf_locals_viewer_get_type (void)
 {
 	static GtkType locals_viewer_type = 0;
 	
@@ -58,7 +58,7 @@ gdf_locals_viewer_get_type ()
 }
 
 GdfLocalsViewer *
-gdf_locals_viewer_new ()
+gdf_locals_viewer_new (void)
 {
 	GdfLocalsViewer *lv;
 	
