@@ -24,6 +24,8 @@
 #include "gdf-register-viewer.h"
 
 struct _GdfRegisterViewerPriv {
+    GtkWidget *vbox;
+    GtkWidget *show_fp;
     GtkWidget *clist;
     GtkWidget *scrolled;
 
@@ -51,9 +53,11 @@ static void set_arg (GtkObject *object,
                      guint arg_id);
 static void connect_debugger_signals (GdfRegisterViewer *rv);
 static void disconnect_debugger_signals (GdfRegisterViewer *rv);
+static void load_registers (GdfRegisterViewer *rv);
 static void execution_stopped_cb (GdfDebuggerClient *dbg,
                                   GdfRegisterViewer *rv);
-
+static void show_fp_toggled_cb (GtkWidget *toggle_bugger, 
+                                GdfRegisterViewer *rv);
 static void create_children (GdfRegisterViewer *rv);
 
 static GtkFrameClass *parent_class;
@@ -237,15 +241,16 @@ disconnect_debugger_signals (GdfRegisterViewer *rv)
 }
 
 void
-execution_stopped_cb (GdfDebuggerClient *dbg, 
-                      GdfRegisterViewer *rv)
+load_registers (GdfRegisterViewer *rv)
 {
     GDF_RegisterList *regs;
     GdfDebuggerClientResult res;
     int i;
     gchar *text[2];
     
-    res = gdf_debugger_client_get_registers (dbg, &regs);
+    res = gdf_debugger_client_get_registers (rv->priv->dbg,
+                                             (gboolean)GTK_TOGGLE_BUTTON (rv->priv->show_fp)->active,
+                                             &regs);
     if (res != GDF_DEBUGGER_CLIENT_OK)
         return;
     
@@ -262,11 +267,30 @@ execution_stopped_cb (GdfDebuggerClient *dbg,
     CORBA_free (regs);
 }
 
+void
+execution_stopped_cb (GdfDebuggerClient *dbg, 
+                      GdfRegisterViewer *rv)
+{
+    load_registers (rv);
+}
+
+void
+show_fp_toggled_cb (GtkWidget *toggle_bugger, GdfRegisterViewer *rv)
+{
+    load_registers (rv);
+}
+
 void
 create_children (GdfRegisterViewer *rv)
 {
     gchar *titles[] = { N_("Reg"), N_("Value") };
     
+    rv->priv->show_fp = 
+        gtk_check_button_new_with_label (_("Include floating point"));
+
+    gtk_signal_connect (GTK_OBJECT (rv->priv->show_fp), "toggled",
+                        GTK_SIGNAL_FUNC (show_fp_toggled_cb), rv);
+
     rv->priv->clist = gtk_clist_new_with_titles (2, titles);
     
     gtk_clist_set_column_width (GTK_CLIST (rv->priv->clist), 0, 40);
@@ -276,9 +300,16 @@ create_children (GdfRegisterViewer *rv)
                                     GTK_POLICY_AUTOMATIC,
                                     GTK_POLICY_AUTOMATIC);
 	
+    rv->priv->vbox = gtk_vbox_new (FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (rv->priv->vbox), rv->priv->show_fp, 
+                        FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (rv->priv->vbox), rv->priv->scrolled,
+                        TRUE, TRUE, 0);
     gtk_container_add (GTK_CONTAINER (rv->priv->scrolled), rv->priv->clist);
-    gtk_container_add (GTK_CONTAINER (rv), rv->priv->scrolled);
+    gtk_container_add (GTK_CONTAINER (rv), rv->priv->vbox);
+    gtk_widget_show (rv->priv->show_fp);
     gtk_widget_show (rv->priv->clist);
     gtk_widget_show (rv->priv->scrolled);
+    gtk_widget_show (rv->priv->vbox);
 }
 
