@@ -194,13 +194,14 @@ gdf_source_viewer_manager_set_debugger (GdfSourceViewerManager *svm,
 	svm->priv->dbg = dbg;
 
     if (dbg) {
+        GDF_Debugger_StateFlag state;
         gtk_object_ref (GTK_OBJECT (dbg));
         if (GTK_OBJECT_FLOATING (GTK_OBJECT (dbg))) 
         gtk_object_sink (GTK_OBJECT (dbg));
         
         connect_debugger_signals (svm);
-        
-        if (svm->priv->dbg->program_loaded) {
+        state = gdf_debugger_client_get_state (svm->priv->dbg);
+        if ((state & GDF_Debugger_BINARY_LOADED) == GDF_Debugger_BINARY_LOADED) {
             fill_sources_combo (svm);
             svm->priv->breakpoint_locations =
                 g_hash_table_new (bp_hash, bp_equal);
@@ -316,7 +317,7 @@ set_arg (GtkObject *object,
     case ARG_DEBUGGER :
         GDF_TRACE ();
         gdf_source_viewer_manager_set_debugger (svm,
-                                                 GTK_VALUE_OBJECT (*arg));
+                                                GTK_VALUE_OBJECT (*arg) ? GDF_DEBUGGER_CLIENT (GTK_VALUE_OBJECT (*arg)) : NULL);
         break;
     default :
         break;
@@ -330,11 +331,16 @@ set_arg (GtkObject *object,
 void
 fill_sources_combo (GdfSourceViewerManager *svm)
 {
-    GDF_source_file_list* sources = 
-        gdf_debugger_client_get_sources (svm->priv->dbg);
+    GdfDebuggerClientResult res;
+    GDF_source_file_list* sources;
     GList *source_names = NULL;
     int i;
-
+    
+    res = gdf_debugger_client_get_sources (svm->priv->dbg, &sources);
+    if (res != GDF_DEBUGGER_CLIENT_OK) {
+        return;
+    }
+    
     /* Move the sources into the list */
     for (i = 0; i < sources->_length; i++) {
         /* FIXME: Allow the user to decide whether they want headers or not */
@@ -397,10 +403,11 @@ check_sources_entry (GdfSourceViewerManager *svm, gchar *filename)
 void
 sources_entry_changed_cb (GtkWidget *entry, GdfSourceViewerManager *svm)
 {
-    gchar *text, *filename;
+    gchar *text, *filename = NULL;
     text = gtk_entry_get_text (GTK_ENTRY (entry));
-    filename = gdf_debugger_client_get_absolute_source_path (svm->priv->dbg,
-                                                              text);
+    gdf_debugger_client_get_absolute_source_path (svm->priv->dbg,
+                                                  text,
+                                                  &filename);
     view_source (svm, filename);
     g_free (filename);
 }
@@ -449,7 +456,7 @@ create_source_page (GdfSourceViewerManager *svm, const gchar *source_path)
 
 	tab_text = strrchr (source_path, G_DIR_SEPARATOR) + 1;
     
-	if (tab_text == 1)
+	if (tab_text == (char*)1)
         tab_text = (char*)source_path;
 	
 	tab_label = gtk_label_new (tab_text);
@@ -557,10 +564,11 @@ add_breakpoint (GdfSourceViewerManager *svm,
 				GDF_Breakpoint *bp)
 {
 	GtkWidget *sv;
-    char *filename;
+    char *filename = NULL;
     
-    filename = gdf_debugger_client_get_absolute_source_path (svm->priv->dbg, 
-                                                              bp->file_name);
+    gdf_debugger_client_get_absolute_source_path (svm->priv->dbg, 
+                                                  bp->file_name,
+                                                  &filename);
     
 	sv = view_source (svm, filename);
 
@@ -598,9 +606,10 @@ enable_breakpoint (GdfSourceViewerManager *svm, gint bp_num, gboolean enabled)
 		gdf_source_viewer_enable_breakpoint (GDF_SOURCE_VIEWER (sv), bp_num,
 											 enabled);
 	} else {
-		GDF_Breakpoint *bp;
-		bp = gdf_debugger_client_get_breakpoint_info (svm->priv->dbg, 
-													   bp_num);
+		GDF_Breakpoint *bp = NULL;
+		gdf_debugger_client_get_breakpoint_info (svm->priv->dbg, 
+                                                 bp_num,
+                                                 &bp);
 
 		g_assert (bp->enabled == TRUE);
 		
@@ -735,9 +744,9 @@ breakpoint_set_cb (GdfDebuggerClient *dbg,
 				   gint bp_num,
 				   GdfSourceViewerManager *svm)
 {
-	GDF_Breakpoint *bp;
+	GDF_Breakpoint *bp = NULL;
 	
-	bp = gdf_debugger_client_get_breakpoint_info (dbg, bp_num);
+	gdf_debugger_client_get_breakpoint_info (dbg, bp_num, &bp);
 
 	add_breakpoint (svm, bp);
 
@@ -803,14 +812,14 @@ void
 frame_changed_cb (GdfDebuggerClient *dbg, gint new_frame,
                   GdfSourceViewerManager *svm)
 {
-    GDF_StackFrame *frame;
+    GDF_StackFrame *frame = NULL;
     GtkWidget *sv;
-    char *full_path;
+    char *full_path = NULL;
 
-    frame = gdf_debugger_client_get_frame (dbg, new_frame);
-    full_path = 
-        gdf_debugger_client_get_absolute_source_path (dbg, 
-                                                       frame->location.file);
+    gdf_debugger_client_get_frame (dbg, new_frame, &frame);
+    gdf_debugger_client_get_absolute_source_path (dbg, 
+                                                  frame->location.file,
+                                                  &full_path);
 
     sv = view_source (svm, full_path);
     gdf_source_viewer_view_line (GDF_SOURCE_VIEWER (sv), 
