@@ -251,7 +251,7 @@ execution_stopped_cb (GdfDebuggerClient *dbg,
 
     res = gdf_debugger_client_get_backtrace (dbg, &stack);
     if (res != GDF_DEBUGGER_CLIENT_OK) {
-        g_assert (FALSE);
+        gtk_clist_clear (GTK_CLIST (sb->priv->clist));
         return;
     }
     
