@@ -80,6 +80,40 @@ static void entry_activate_cb (GtkWidget *btn, gpointer data);
 static void tree_expand_cb (GtkWidget *ctree, GtkCTreeNode *node, 
                             gpointer data);
 static gint int_cmp (gconstpointer a, gconstpointer b);
+static void do_popup (GdfVariableViewer *vv, int symbol_id);
+static gint button_press_cb (GtkWidget *ctree, GdkEventButton *event, 
+							 GdfVariableViewer *vv);
+static void set_value_selected_cb (GtkWidget *widget, 
+                                   GdfVariableViewer *vv);
+static void cast_selected_cb (GtkWidget *widget, 
+                              GdfVariableViewer *vv);
+
+static GnomeUIInfo popup_menu[] =
+{
+    {
+        GNOME_APP_UI_ITEM,
+        N_("Set value"),
+        N_("Set the value of the expression."),
+        set_value_selected_cb,
+        NULL,
+        NULL,
+        GNOME_APP_PIXMAP_STOCK,
+        GNOME_STOCK_MENU_INDEX,
+        0, 0, NULL
+    },
+    {
+        GNOME_APP_UI_ITEM,
+        N_("Cast"),
+        N_("Cast the expression to a different type"),
+        cast_selected_cb,
+        NULL,
+        NULL,
+        GNOME_APP_PIXMAP_STOCK,
+        GNOME_STOCK_MENU_CONVERT,
+        0, 0, NULL
+    }, 
+    GNOMEUIINFO_END
+};
 
 static GtkFrameClass *parent_class;
 
@@ -354,6 +388,8 @@ create_children (GdfVariableViewer *vv)
 	
     gtk_signal_connect (GTK_OBJECT (vv->priv->ctree), "tree_expand",
                         GTK_SIGNAL_FUNC (tree_expand_cb), vv);
+	gtk_signal_connect (GTK_OBJECT (vv->priv->ctree), "button_press_event",
+						GTK_SIGNAL_FUNC (button_press_cb), vv);
 
     gtk_clist_set_column_width (GTK_CLIST (vv->priv->ctree), 0, 150);
 
@@ -443,7 +479,7 @@ symbol_set_changed_cb (GdfSymbolSetClient *ss, GdfVariableViewer *vv)
 
     gdf_variable_viewer_clear (vv);
 
-    syms = gdf_symbol_set_client_get_symbols (ss);
+    gdf_symbol_set_client_get_symbols (ss, &syms);
     
     if (syms->_length > 0)
         vv->priv->nodes = g_tree_new (int_cmp);
@@ -464,7 +500,7 @@ symbol_changed_cb (GdfSymbolSetClient *ss, int handle, GdfVariableViewer *vv)
     GtkCTreeNode *child;
     GtkCTreeRow *row;
 
-    sym = gdf_symbol_set_client_get_symbol (ss, handle);
+    gdf_symbol_set_client_get_symbol (ss, handle, &sym);
 
     node = g_tree_lookup (vv->priv->nodes, GINT_TO_POINTER (handle));
     row = GTK_CTREE_ROW (node);
@@ -488,7 +524,7 @@ symbol_type_changed_cb (GdfSymbolSetClient *ss, int handle,
     GtkCTreeNode *child;
     GtkCTreeRow *row;
 
-    sym = gdf_symbol_set_client_get_symbol (ss, handle);
+    gdf_symbol_set_client_get_symbol (ss, handle, &sym);
     
     node = g_tree_lookup (vv->priv->nodes, GINT_TO_POINTER (handle));
     row = GTK_CTREE_ROW (node);
@@ -607,7 +643,7 @@ tree_expand_cb (GtkWidget *ctree, GtkCTreeNode *node, gpointer data)
         sym_id = 
             GPOINTER_TO_INT (gtk_ctree_node_get_row_data (GTK_CTREE (ctree), 
                                                           node));
-        seq = gdf_symbol_set_client_get_symbol_children (vv->priv->ss, sym_id);
+        gdf_symbol_set_client_get_symbol_children (vv->priv->ss, sym_id, &seq);
 
         /* Remove the old/dummy children */
         child = GTK_CTREE_ROW (node)->children;
@@ -637,3 +673,191 @@ int_cmp (gconstpointer a, gconstpointer b)
             ? -1 
             : (GPOINTER_TO_INT (a) == GPOINTER_TO_INT (b) ? 0 : 1));
 }
+
+void
+do_popup (GdfVariableViewer *vv, int symbol_id)
+{
+	GtkWidget *menu = NULL;
+
+	gtk_object_set_data (GTK_OBJECT (vv), "symbol_id", 
+                         GINT_TO_POINTER (symbol_id));
+
+    popup_menu[0].user_data = vv;
+    popup_menu[0].user_data = vv;
+
+	menu = gnome_popup_menu_new (popup_menu);
+	gnome_popup_menu_do_popup (menu, NULL, NULL, NULL, (gpointer)vv);
+}
+
+gint
+button_press_cb (GtkWidget *widget, GdkEventButton *event, 
+				 GdfVariableViewer *vv)
+{
+	gint row;
+    int sym_id;
+    GDF_Symbol *sym;
+
+	if (!gtk_clist_get_selection_info (GTK_CLIST (widget), 
+									   (gint)event->x, (gint)event->y,
+									   &row, NULL))
+		return TRUE;
+    
+    sym_id = GPOINTER_TO_INT (gtk_ctree_node_get_row_data (GTK_CTREE (vv->priv->ctree),
+                                                           gtk_ctree_node_nth (GTK_CTREE (vv->priv->ctree), row)));
+
+    gdf_symbol_set_client_get_symbol (vv->priv->ss, sym_id, &sym);
+
+	if (sym->type != GDF_TYPE_ARRAY_SLICE && event->button == 3)
+		do_popup (vv, sym_id);
+
+    CORBA_free (sym);
+
+	return FALSE;
+}
+
+void 
+set_value_selected_cb (GtkWidget *widget, 
+                       GdfVariableViewer *vv)
+{
+    int sym_id;
+    GDF_Symbol *sym;
+    GtkWidget *dlg;
+    GtkWidget *entry;
+    GtkWidget *label;
+    GtkWidget *hbox;
+    GdfDebuggerClientResult res;
+    char *errmsg;
+    int btn;
+    char *value;
+    
+    sym_id = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (vv), 
+                                                   "symbol_id"));
+    gdf_symbol_set_client_get_symbol (vv->priv->ss, sym_id, &sym);
+    
+    label = gtk_label_new (_("Value :"));
+    entry = gnome_entry_new ("gdf_value");
+
+    gtk_entry_set_text (GTK_ENTRY(gnome_entry_gtk_entry (GNOME_ENTRY (entry))),
+                        sym->value);
+
+    CORBA_free (sym);
+
+    hbox = gtk_hbox_new (FALSE, 5);
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
+    
+    dlg = gnome_dialog_new (_("Set Value"), GNOME_STOCK_BUTTON_OK, 
+                            GNOME_STOCK_BUTTON_CANCEL, NULL);
+
+    gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dlg)->vbox), hbox, 
+                        TRUE, TRUE, 0);
+
+    gtk_widget_show (label);
+    gtk_widget_show (entry);
+    gtk_widget_show (hbox);
+
+    btn = gnome_dialog_run (GNOME_DIALOG (dlg));
+    
+    if (btn != 0) {
+        gnome_dialog_close (GNOME_DIALOG (dlg));
+        return;
+    }
+    
+    value = gtk_editable_get_chars (GTK_EDITABLE (gnome_entry_gtk_entry (GNOME_ENTRY (entry))), 0, -1);
+
+    res = gdf_symbol_set_client_set_symbol_value (vv->priv->ss, sym_id, value);
+    
+    gnome_dialog_close (GNOME_DIALOG (dlg));
+
+    errmsg = NULL;
+    switch (res) {
+    case GDF_SYMBOL_SET_CLIENT_OK :
+        break;
+    case GDF_SYMBOL_SET_CLIENT_INVALID_TYPE :
+        errmsg = _("Invalid type.");
+        break;
+    default :
+        g_assert_not_reached ();
+    }
+
+    if (errmsg) {
+        errmsg = 
+            g_strdup_printf (_("Could not set value: %s"), errmsg);
+        dlg = gnome_error_dialog (errmsg);
+        gnome_dialog_run_and_close (GNOME_DIALOG (dlg));
+    }
+}
+
+void 
+cast_selected_cb (GtkWidget *widget, 
+                       GdfVariableViewer *vv)
+{
+    int sym_id;
+    GDF_Symbol *sym;
+    GtkWidget *dlg;
+    GtkWidget *entry;
+    GtkWidget *label;
+    GtkWidget *hbox;
+    GdfDebuggerClientResult res;
+    char *errmsg;
+    int btn;
+    char *type;
+    
+    sym_id = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (vv), 
+                                                   "symbol_id"));
+    gdf_symbol_set_client_get_symbol (vv->priv->ss, sym_id, &sym);
+    
+    label = gtk_label_new (_("Cast to :"));
+    entry = gnome_entry_new ("gdf_value");
+
+    gtk_entry_set_text (GTK_ENTRY(gnome_entry_gtk_entry (GNOME_ENTRY (entry))),
+                        sym->cast_to);
+
+    CORBA_free (sym);
+
+    hbox = gtk_hbox_new (FALSE, 5);
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
+    
+    dlg = gnome_dialog_new (_("Cast"), GNOME_STOCK_BUTTON_OK, 
+                            GNOME_STOCK_BUTTON_CANCEL, NULL);
+
+    gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dlg)->vbox), hbox, 
+                        TRUE, TRUE, 0);
+
+    gtk_widget_show (label);
+    gtk_widget_show (entry);
+    gtk_widget_show (hbox);
+
+    btn = gnome_dialog_run (GNOME_DIALOG (dlg));
+    
+    if (btn != 0) {
+        gnome_dialog_close (GNOME_DIALOG (dlg));
+        return;
+    }
+    
+    type = gtk_editable_get_chars (GTK_EDITABLE (gnome_entry_gtk_entry (GNOME_ENTRY (entry))), 0, -1);
+
+    res = gdf_symbol_set_client_cast (vv->priv->ss, sym_id, type);
+    
+    gnome_dialog_close (GNOME_DIALOG (dlg));
+
+    errmsg = NULL;
+    switch (res) {
+    case GDF_SYMBOL_SET_CLIENT_OK :
+        break;
+    case GDF_SYMBOL_SET_CLIENT_INVALID_TYPE :
+        errmsg = _("Invalid type.");
+        break;
+    default :
+        g_assert_not_reached ();
+    }
+
+    if (errmsg) {
+        errmsg = 
+            g_strdup_printf (_("Could not cast: %s"), errmsg);
+        dlg = gnome_error_dialog (errmsg);
+        gnome_dialog_run_and_close (GNOME_DIALOG (dlg));
+    }
+}
+
