@@ -50,9 +50,9 @@ struct _GdfVariableViewerClass {
     void (*debugger_set) (GdfVariableViewer *vv, GdfDebuggerClient *client);
 };
 
-GtkType gdf_variable_viewer_get_type ();
+GtkType gdf_variable_viewer_get_type (void);
 
-GdfVariableViewer *gdf_variable_viewer_new ();
+GdfVariableViewer *gdf_variable_viewer_new (void);
 
 void gdf_variable_viewer_view_symbol_set (GdfVariableViewer *vv,
                                           GdfSymbolSetClient *ss);
