@@ -587,6 +587,7 @@ gdf_debugger_client_get_breakpoint_info (GdfDebuggerClient *dbg,
 
 GdfDebuggerClientResult
 gdf_debugger_client_get_registers (GdfDebuggerClient *dbg,
+                                   gboolean floating_pt,
                                    GDF_RegisterList **ret)
 {
     CORBA_Environment ev;
@@ -599,6 +600,7 @@ gdf_debugger_client_get_registers (GdfDebuggerClient *dbg,
 
     CORBA_exception_init (&ev);
     *ret = GDF_Debugger_get_registers (dbg->objref,
+                                       floating_pt,
                                        &ev);
     
     res = exception_to_result (&ev);
